# Quickstart

# Installation
### Requirements
* **Python**: 3.12 or higher

### Installing the Library

`pqlattice` is available on PyPI

=== "pip"
    ```bash
    pip install zxcv
    ```
=== "uv"
    ```bash
    uv add zxcv
    ```

# Basis usage

```python
import pqlattice as pq
```
